**NEN-EN 1992-1-1:2005+A1:2015+NB:2016+A1:2020 - February 2020
Eurocode 2: Design of concrete structures
Part 1-1: General rules and rules for buildings**

The table presents a list of tables from the Eurocode 2 standards for concrete structures, tracking their implementation status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 38 tables present.

| Table number |        Done        | Remarks | Object name                                         |
|:-------------|:------------------:|:--------|:----------------------------------------------------|
| 2.1N         |        :x:         |         |                                                     |
| 3.1          |        :x:         |         |                                                     |
| 3.2          |        :x:         |         |                                                     |
| 3.3          |        :x:         |         |                                                     |
| 3.4          |        :x:         |         |                                                     |
| 4.1          | :heavy_check_mark: |         | Table4Dot1ExposureClasses                           |
| 4.2          | :heavy_check_mark: |         | Table4Dot2MinimumCoverWithRegardToBond              |
| 4.3N         | :heavy_check_mark: |         | Table4Dot3ConcreteStructuralClass                   |
| 4.4N         | :heavy_check_mark: |         | Table4Dot4nMinimumCoverDurabilityReinforcementSteel |
| 4.5N         | :heavy_check_mark: |         | Table4Dot5nMinimumCoverDurabilityPrestressingSteel  |
| 5.1          |        :x:         |         |                                                     |
| 6.1          |        :x:         |         |                                                     |
| 6.2          |        :x:         |         |                                                     |
| 6.3N         |        :x:         |         |                                                     |
| 6.4N         |        :x:         |         |                                                     |
| 7.1N         |        :x:         |         |                                                     |
| 7.2N         |        :x:         |         |                                                     |
| 7.3N         |        :x:         |         |                                                     |
| 7.4N         |        :x:         |         |                                                     |
| 8.1N         |        :x:         |         |                                                     |
| 8.2          |        :x:         |         |                                                     |
| 8.3          |        :x:         |         |                                                     |
| 8.4          |        :x:         |         |                                                     |
| 9.6N         |        :x:         |         |                                                     |
| 10.2         |        :x:         |         |                                                     |
| 10.3         |        :x:         |         |                                                     |
| 10.4         |        :x:         |         |                                                     |
| 10.5         |        :x:         |         |                                                     |
| 11.1         |        :x:         |         |                                                     |
| 11.3.1       |        :x:         |         |                                                     |
| 11.6.1N      |        :x:         |         |                                                     |
| 12.1         |        :x:         |         |                                                     |
| A.1          |        :x:         |         |                                                     |
| C.1          |        :x:         |         |                                                     |
| C.2N         |        :x:         |         |                                                     |
| C.3N         |        :x:         |         |                                                     |
| E.1N         |        :x:         |         |                                                     |
| I.1          |        :x:         |         |                                                     |

